@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: tagged
-version: 0.8.3
-id: tagged-0.8.3-aa128de4449752177a05765fb0ce3959
-key: tagge_5cptKNCoGdxJM6eqqNERxD
+version: 0.8.4
+id: tagged-0.8.4-af2e23230031c45949e0062e776a8f1f
+key: tagge_LPeicl3HxVfGUMMwMEsAE6
 license: BSD3
 copyright: 2009-2015 Edward A. Kmett
 maintainer: Edward A. Kmett <ekmett@gmail.com>
@@ -18,10 +18,10 @@ exposed: True
 exposed-modules:
     Data.Tagged Data.Proxy.TH
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/tagged-0.8.3
-library-dirs: /usr/lib/ghc-7.10.3/site-local/tagged-0.8.3
-data-dir: /usr/share/arm-linux-ghc-7.10.3/tagged-0.8.3
-hs-libraries: HStagged-0.8.3-5cptKNCoGdxJM6eqqNERxD
+import-dirs: /usr/lib/ghc-7.10.3/site-local/tagged-0.8.4
+library-dirs: /usr/lib/ghc-7.10.3/site-local/tagged-0.8.4
+data-dir: /usr/share/arm-linux-ghc-7.10.3/tagged-0.8.4
+hs-libraries: HStagged-0.8.4-LPeicl3HxVfGUMMwMEsAE6
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
